@@ -4,6 +4,7 @@ import os
 from tabulate import tabulate
 
 from nextcode.services.query.exceptions import MissingRelations, QueryError
+from nextcode.exceptions import ServerError
 
 from ...queryapi import get_results
 from ...utils import get_logger, abort, print_tab, dumps
@@ -262,6 +263,36 @@ def progress(ctx, query_id, is_raw):
     click.echo(tbl)
 
 
+@click.command()
+@click.argument('query_id', nargs=1)
+@click.option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
+@click.pass_context
+@check_project
+def details(ctx, query_id, is_raw):
+    """
+    View runtime details for a query
+    """
+    svc = ctx.obj.service
+
+    qry = svc.get_query(query_id)
+    url = qry.links['details']
+    resp = svc.session.get(url)
+    details = resp.json()['details']
+    if not details:
+        abort("No details found for query")
+
+    if is_raw:
+        click.echo(dumps(details))
+        return
+
+    print_tab("requestId", details['requestId'])
+    click.secho("Tasks", bold=True)
+    for task_name, task in details.get("tasks", {}).items():
+        print(task_name)
+        for k in sorted(task.keys()):
+            print_tab(f" {k}", task[k])
+        print("")
+
 @click.command("list")
 @click.option('-u', '--user', 'user_name', help='User to filter for')
 @click.option('-s', '--status', 'status', default=None, help='Filter status')
@@ -281,7 +312,10 @@ def list_queries(ctx, user_name, status, num, is_raw, is_all):
     svc = ctx.obj.service
     if is_all and user_name:
         abort("You cannot use the --all flag and the --user parameter together")
-    queries = svc.get_queries(limit=num, user_name=user_name, all=is_all)
+    try:
+        queries = svc.get_queries(limit=num, user_name=user_name, all=is_all)
+    except ServerError as e:
+        abort(e)
     if is_raw:
         click.echo(dumps([q.raw for q in queries]))
         return
